=begin

Copyright 2011, Alexander C. Schreyer
All rights reserved

THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
FITNESS FOR A PARTICULAR PURPOSE.

License:        GPL (http://www.gnu.org/licenses/gpl.html)

Author :        Alexander Schreyer, www.alexschreyer.net, mail@alexschreyer.net
Website:        http://www.sketchupplugins.com

Name :          PluginWebLoader
Version:        0.6
Date :          11/9/2011

Description :   Adds a menu item to the Window menu that allows for browsing 
				www.sketchupplugins.com and installing (almost directly) from that site.
Usage :         Install this plugin and browse or search www.sketchupplugins.com. 
				Then look for the "Install" button to install the plugin using
				SketchUp v8 M2's install extension functionality.

History:        0.5 (11/9/2011) - first version
				0.6 (1/3/2012) - changed installation routine to use browser instead

TODO List:      - Would be great to be able to use install_from_archive with URL as parameter.
					That would make this a one-click installer.
				- Could add list of currently installed plugins.
				- Might add links to other websites as well.

=end

require 'sketchup.rb'


module AS_ws_loader

  
  def self.install_from_webdlg(url)
    
    dlg = UI::WebDialog.new("Find and Install Plugins from www.sketchupplugins.com", true,
      "Plugin WS Browser", 960, 750, 150, 150, true);
    dlg_html = "<html><head><meta http-equiv=\"MSThemeCompatible\" content=\"Yes\"></head><body style=\"margin:0;padding:0;font-family:Arial,Helvetica,sans-serif;font-size:9pt;color:#fff;background-color:#666;overflow:hidden;\"><div id=\"header\" style=\"height:30px;padding:10px;\">"
    if !(Object::RUBY_PLATFORM.include? "darwin") # Only do this in Windows, javascript history doesn't work well on macs
      dlg_html += "<p style=\"width:20%;height:100%;float:left;\"><a href=\"javascript:history.back();\" style=\"color:#fff\">&laquo;BACK</a> | <a href=\"javascript:location.reload();\" style=\"color:#fff\">RELOAD</a> | <a href=\"javascript:history.forward()\" style=\"color:#fff\">NEXT&raquo;</a></p>"
    end
    dlg_html += "<p style=\"width:80%;float:right;text-align:left;\">Browse to a plugin and follow the installation instructions. <a href=\"skp:manage_plugins\" style=\"color:#FDD017;font-weight:bold;\">Show currently installed Plugins</a></p></div><iframe style=\"clear:both;\" name=\"browser\" align=\"bottom\" id=\"browser\" src=\"#{url}\" width=\"100%\" height=\"100%\" scrolling=\"auto\" noresize=\"noresize\" frameborder=\"no\"></iframe></body></html>"
    dlg.set_html(dlg_html)
    dlg.navigation_buttons_enabled = true
    
    # Callback to install a plugin using URL parameter from site
  	dlg.add_action_callback("install_plugin") do |dlg, params|
  		if (Sketchup.version_number < 8000999)
  			UI.messagebox "Can't install plugins this way! SketchUp v.8 M2 (maintenance release 2) 
  			or newer is needed for installer functionality. You can still download
  			the plugin and install it manually into SketchUp's Plugin folder."
  		else
    		result = UI.messagebox "Do you want to install this plugin now?", MB_YESNOCANCEL 
    		if result == 6
          begin
            Sketchup.install_from_archive(params)
			UI.messagebox "The plugin was successfully installed and should be available now."
          rescue Interrupt => error
            UI.messagebox "Cancelled installation: " + error
          rescue Exception => error
            UI.messagebox "Error during installation: " + error
          end
    		end
    	end
  	end # callback install_plugin
	
    # Callback to install a plugin using browser and URL parameter from site
  	dlg.add_action_callback("install_plugin_via_browser") do |dlg, params|
  		if (Sketchup.version_number < 8000999)
  			UI.messagebox "Can't install plugins this way! SketchUp v.8 M2 (maintenance release 2) 
  			or newer is needed for installer functionality. You can still download
  			the plugin and install it manually into SketchUp's Plugin folder."
  		else
			result = UI.messagebox "After clicking OK, your browser will open and download the plugin file (an RBZ file) to the browser's default download location (it might ask you to select a location on your harddisk).\n\nRemember the location, close the browser and return to SketchUp. A dialog will be open. Use it to browse to the RBZ file you just downloaded.\n\nSketchUp will then guide you through the installation process.", MB_OKCANCEL 
    		if result == 1
				begin
				UI.openURL params
				filename = UI.openpanel "Browse to the RBZ or ZIP file you just downloaded to install it", "", "*.rbz;*.zip" 
				if filename
					Sketchup.install_from_archive(filename)
					UI.messagebox "The plugin was successfully installed and should be available now."
				end	
				rescue Interrupt => error
				UI.messagebox "Cancelled installation: " + error
				rescue Exception => error
				UI.messagebox "Error during installation: " + error
				end
    		end
    	end
  	end # callback install_plugin_via_browser	
  	
  	# Callback to install a plugin from a local location
  	dlg.add_action_callback("install_local_plugin") do |dlg, params|
      if (Sketchup.version_number < 8000999)
        UI.messagebox "Can't install plugins this way! SketchUp v.8 M2 (maintenance release 2) 
        or newer is needed for installer functionality. You can still download
        the plugin and install it manually into SketchUp's Plugin folder."
      else
        # result = UI.messagebox "Do you want to install a plugin now?", MB_YESNOCANCEL 
        # if result == 6
          filename = UI.openpanel "Select RBZ or ZIP plugin installer file", "", "*.rbz;*.zip"
          if filename
            begin
              Sketchup.install_from_archive(filename)
			  UI.messagebox "The plugin was successfully installed and should be available now."
            rescue Interrupt => error
              UI.messagebox "Cancelled installation: " + error
            rescue Exception => error
              UI.messagebox "Error during installation: " + error
            end
          end
        # end
      end
    end # callback install_local_plugin
	
	# Callback to show the installed plugins
  	dlg.add_action_callback("manage_plugins") do |dlg, params|
		UI.show_preferences "Extensions"
    end # callback install_local_plugin   
	
    dlg.show_modal
    
  end # install_from_webdlg

  
end # module


# ==================================================== #


if !file_loaded?(__FILE__)

  # get the SketchUp Window menu
  UI.menu("Window").add_item("Find and Install Plugins...") {
      AS_ws_loader::install_from_webdlg("http://www.sketchupplugins.com") }
  
  # Let Ruby know we have loaded this file
  file_loaded(__FILE__)

end  